import { __extends } from "tslib";
import { BatchDescribeTypeConfigurationsInput, BatchDescribeTypeConfigurationsOutput } from "../models/models_0";
import { deserializeAws_queryBatchDescribeTypeConfigurationsCommand, serializeAws_queryBatchDescribeTypeConfigurationsCommand, } from "../protocols/Aws_query";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Returns configuration data for the specified CloudFormation extensions, from the CloudFormation registry for the account and region.</p>
 *          <p>For more information, see <a href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-register.html#registry-set-configuration">Configuring extensions at the account level</a> in the <i>CloudFormation User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, BatchDescribeTypeConfigurationsCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, BatchDescribeTypeConfigurationsCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const command = new BatchDescribeTypeConfigurationsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link BatchDescribeTypeConfigurationsCommandInput} for command's `input` shape.
 * @see {@link BatchDescribeTypeConfigurationsCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for command's `input` shape.
 *
 */
var BatchDescribeTypeConfigurationsCommand = /** @class */ (function (_super) {
    __extends(BatchDescribeTypeConfigurationsCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function BatchDescribeTypeConfigurationsCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    BatchDescribeTypeConfigurationsCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "CloudFormationClient";
        var commandName = "BatchDescribeTypeConfigurationsCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: BatchDescribeTypeConfigurationsInput.filterSensitiveLog,
            outputFilterSensitiveLog: BatchDescribeTypeConfigurationsOutput.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    BatchDescribeTypeConfigurationsCommand.prototype.serialize = function (input, context) {
        return serializeAws_queryBatchDescribeTypeConfigurationsCommand(input, context);
    };
    BatchDescribeTypeConfigurationsCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_queryBatchDescribeTypeConfigurationsCommand(output, context);
    };
    return BatchDescribeTypeConfigurationsCommand;
}($Command));
export { BatchDescribeTypeConfigurationsCommand };
//# sourceMappingURL=BatchDescribeTypeConfigurationsCommand.js.map