import { __extends } from "tslib";
import { DeactivateTypeInput, DeactivateTypeOutput } from "../models/models_0";
import { deserializeAws_queryDeactivateTypeCommand, serializeAws_queryDeactivateTypeCommand, } from "../protocols/Aws_query";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Deactivates a public extension that was previously activated in this account and region.</p>
 *          <p>Once deactivated, an extension cannot be used in any CloudFormation operation. This includes stack update operations where the stack template includes the extension, even if no updates are being made to the extension. In addition, deactivated extensions are not automatically updated if a new version of the extension is released.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, DeactivateTypeCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, DeactivateTypeCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const command = new DeactivateTypeCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DeactivateTypeCommandInput} for command's `input` shape.
 * @see {@link DeactivateTypeCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for command's `input` shape.
 *
 */
var DeactivateTypeCommand = /** @class */ (function (_super) {
    __extends(DeactivateTypeCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function DeactivateTypeCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    DeactivateTypeCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "CloudFormationClient";
        var commandName = "DeactivateTypeCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: DeactivateTypeInput.filterSensitiveLog,
            outputFilterSensitiveLog: DeactivateTypeOutput.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    DeactivateTypeCommand.prototype.serialize = function (input, context) {
        return serializeAws_queryDeactivateTypeCommand(input, context);
    };
    DeactivateTypeCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_queryDeactivateTypeCommand(output, context);
    };
    return DeactivateTypeCommand;
}($Command));
export { DeactivateTypeCommand };
//# sourceMappingURL=DeactivateTypeCommand.js.map