import { __extends } from "tslib";
import { StopStackSetOperationInput, StopStackSetOperationOutput } from "../models/models_0";
import { deserializeAws_queryStopStackSetOperationCommand, serializeAws_queryStopStackSetOperationCommand, } from "../protocols/Aws_query";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Stops an in-progress operation on a stack set and its associated stack instances. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, StopStackSetOperationCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, StopStackSetOperationCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const command = new StopStackSetOperationCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link StopStackSetOperationCommandInput} for command's `input` shape.
 * @see {@link StopStackSetOperationCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for command's `input` shape.
 *
 */
var StopStackSetOperationCommand = /** @class */ (function (_super) {
    __extends(StopStackSetOperationCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function StopStackSetOperationCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    StopStackSetOperationCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "CloudFormationClient";
        var commandName = "StopStackSetOperationCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: StopStackSetOperationInput.filterSensitiveLog,
            outputFilterSensitiveLog: StopStackSetOperationOutput.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    StopStackSetOperationCommand.prototype.serialize = function (input, context) {
        return serializeAws_queryStopStackSetOperationCommand(input, context);
    };
    StopStackSetOperationCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_queryStopStackSetOperationCommand(output, context);
    };
    return StopStackSetOperationCommand;
}($Command));
export { StopStackSetOperationCommand };
//# sourceMappingURL=StopStackSetOperationCommand.js.map