import { __extends } from "tslib";
import { AssociateInstanceEventWindowRequest, AssociateInstanceEventWindowResult } from "../models/models_0";
import { deserializeAws_ec2AssociateInstanceEventWindowCommand, serializeAws_ec2AssociateInstanceEventWindowCommand, } from "../protocols/Aws_ec2";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Associates one or more targets with an event window. Only one type of target (instance IDs,
 *          Dedicated Host IDs, or tags) can be specified with an event window.</p>
 *          <p>For more information, see <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/event-windows.html">Define event windows for scheduled
 *             events</a> in the <i>Amazon EC2 User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, AssociateInstanceEventWindowCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, AssociateInstanceEventWindowCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new AssociateInstanceEventWindowCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link AssociateInstanceEventWindowCommandInput} for command's `input` shape.
 * @see {@link AssociateInstanceEventWindowCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for command's `input` shape.
 *
 */
var AssociateInstanceEventWindowCommand = /** @class */ (function (_super) {
    __extends(AssociateInstanceEventWindowCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function AssociateInstanceEventWindowCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    AssociateInstanceEventWindowCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "EC2Client";
        var commandName = "AssociateInstanceEventWindowCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: AssociateInstanceEventWindowRequest.filterSensitiveLog,
            outputFilterSensitiveLog: AssociateInstanceEventWindowResult.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    AssociateInstanceEventWindowCommand.prototype.serialize = function (input, context) {
        return serializeAws_ec2AssociateInstanceEventWindowCommand(input, context);
    };
    AssociateInstanceEventWindowCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_ec2AssociateInstanceEventWindowCommand(output, context);
    };
    return AssociateInstanceEventWindowCommand;
}($Command));
export { AssociateInstanceEventWindowCommand };
//# sourceMappingURL=AssociateInstanceEventWindowCommand.js.map